@@ -15,7 +15,6 @@ from gi.repository import Gtk, Gdk, GObject, GLib, Gio, Pango
 from gettext import gettext as _
 from time import mktime, time
 from datetime import datetime
-from dateutil import tz
 from locale import strcoll
 from urllib.parse import urlparse
 
@@ -90,24 +89,21 @@ class Row(Gtk.ListBoxRow):
         if favicon is not None:
             grid.attach(favicon, 0, 0, 1, 2)
 
-        self.__title = Gtk.Label.new(title)
+        uri = item.get_property("uri")
+        self.__title = Gtk.Label.new()
         self.__title.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title.set_property("halign", Gtk.Align.START)
         self.__title.set_hexpand(True)
         self.__title.set_property('has-tooltip', True)
         self.__title.connect('query-tooltip', self.__on_query_tooltip)
         self.__title.show()
-        grid.attach(self.__title, 1, 0, 1, 1)
-
-        if favicon is not None:
-            uri = Gtk.Label.new(item.get_property("uri"))
-            uri.set_ellipsize(Pango.EllipsizeMode.END)
-            uri.set_property("halign", Gtk.Align.START)
-            uri.get_style_context().add_class("dim-label")
-            uri.set_property('has-tooltip', True)
-            uri.connect('query-tooltip', self.__on_query_tooltip)
-            uri.show()
-            grid.attach(uri, 1, 1, 1, 1)
+        if uri:
+            self.__title.set_markup("%s\n<span alpha='40000'>%s</span>" %
+                                    (GLib.markup_escape_text(title),
+                                     GLib.markup_escape_text(uri)))
+        else:
+            self.__title.set_text(title)
+        grid.attach(self.__title, 1, 0, 1, 2)
 
         if item_type == Type.HISTORY:
             dt = datetime.fromtimestamp(item.get_property("atime"))
@@ -656,7 +652,7 @@ class UriPopover(Gtk.Popover):
             @param widget as Gtk.Widget
             @param event as Gdk.EventButton
         """
-        # https://bugzilla.gnome.org/show_bug.cgi?id=733108
+        # https://gitlab.gnome.org/GNOME/gtk/issues/497
         self.__modifier = event.state
 
     def _on_sync_button_clicked(self, button):
@@ -683,10 +679,10 @@ class UriPopover(Gtk.Popover):
             @param button as Gtk.Button
         """
         for row in self.__bookmarks_box.get_selected_rows():
-            if App().sync_worker is not None:
-                guid = App().bookmarks.get_guid(self.__bookmark_id)
-                App().sync_worker.remove_from_bookmarks(guid)
             item_id = row.item.get_property("id")
+            if App().sync_worker is not None:
+                guid = App().bookmarks.get_guid(item_id)
+                App().sync_worker.remove_from_bookmarks(guid)
             App().bookmarks.remove(item_id)
             self.__bookmarks_box.remove(row)
             self.__remove_button.hide()
@@ -805,7 +801,7 @@ class UriPopover(Gtk.Popover):
             @param calendar as Gtk.Calendar
         """
         (year, month, day) = calendar.get_date()
-        date = datetime(year, month + 1, day, 0, 0, tzinfo=tz.tzutc())
+        date = datetime(year, month + 1, day, 0, 0)
         atime = mktime(date.timetuple())
         result = App().history.get(atime)
         self.__history_model.remove_all()
