@@ -118,7 +118,9 @@ class PageChildRow(Gtk.ListBoxRow):
         """
         if event in [WebKit2.LoadEvent.STARTED,
                      WebKit2.LoadEvent.COMMITTED]:
-            self.__label.set_text(webview.get_uri())
+            uri = webview.get_uri()
+            if uri is not None:
+                self.__label.set_text(uri)
 
     def __on_webview_title_changed(self, webview, title):
         """
@@ -356,21 +358,14 @@ class SitesManagerChild(Gtk.ListBoxRow):
                 return True
             elif event.button == 3:
                 from eolie.menu_sites import SitesMenu
-                # from eolie.menu_profiles import ProfilesMenu
                 from eolie.menu_move_to import MoveToMenu
                 sites_menu = SitesMenu(self.__views, self.__window)
                 sites_menu.show()
-                # webview = self.__views[0].webview
-                # profiles_menu = ProfilesMenu(webview, self.__window)
-                # profiles_menu.show()
                 moveto_menu = MoveToMenu(self.__views, self.__window)
                 moveto_menu.show()
                 popover = Gtk.PopoverMenu.new()
                 popover.add(sites_menu)
-                # popover.add(profiles_menu)
                 popover.add(moveto_menu)
-                # popover.child_set_property(profiles_menu,
-                #                           "submenu", "profiles")
                 popover.child_set_property(moveto_menu,
                                            "submenu", "moveto")
                 popover.set_relative_to(eventbox)
