@@ -100,7 +100,6 @@ class ToolbarTitle(Gtk.Bin):
         self.__secure_content = True
         self.__size_allocation_timeout = Type.NONE  # CSS update needed
         self.__width = -1
-        self.__uri = ""
         self.__cancellable = Gio.Cancellable.new()
         self.__dns_suffixes = ["com", "org"]
         for string in reversed(GLib.get_language_names()):
@@ -152,14 +151,15 @@ class ToolbarTitle(Gtk.Bin):
         self.__signal_id = self.__entry.connect("changed",
                                                 self.__on_entry_changed)
 
-    def set_reading(self):
+    def set_readable_button_state(self, reading):
         """
             Mark readable button
+            @param reading as bool
         """
         if self.__indicator_stack.get_visible_child_name() != "image":
             return
         child = self.__indicator_stack.get_visible_child()
-        if self.__window.container.current.reading:
+        if reading:
             child.get_style_context().add_class("selected")
         else:
             child.get_style_context().remove_class("selected")
@@ -224,25 +224,12 @@ class ToolbarTitle(Gtk.Bin):
         self.__signal_id = self.__entry.connect("changed",
                                                 self.__on_entry_changed)
 
-    def add_dot_com(self):
+    def update(self):
         """
-            Add dot com to URI
-        """
-        bounds = self.__entry.get_selection_bounds()
-        if bounds:
-            current = self.__entry.get_text()[:bounds[0]]
-        else:
-            current = self.__entry.get_text()
-        self.set_text_entry(current + ".com")
-
-    def set_uri(self, uri):
-        """
-            Update internal uri
+            Update toolbar based on current webview
             @param text as str
         """
-        if uri == self.__uri:
-            return
-        self.__uri = uri
+        uri = self.__window.container.current.webview.uri
         self.set_tooltip_text(uri)
         self.__input_warning_shown = False
         self.__secure_content = True
@@ -255,20 +242,16 @@ class ToolbarTitle(Gtk.Bin):
         self.__action_image2.set_from_icon_name(icon_name,
                                                 Gtk.IconSize.MENU)
 
-    def set_title(self, profile, title):
+    def set_title(self, title):
         """
             Show title instead of uri
-            @param profile as str
             @param title as str
         """
         self.__window.set_title(title)
         markup = False
-        if profile:
-            markup = True
-            title = "<b>%s</b>%s" % (GLib.markup_escape_text(profile),
-                                     GLib.markup_escape_text(title))
         # Do not show this in titlebar
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         if parsed.scheme in ["populars", "about"]:
             self.__set_default_placeholder()
             return
@@ -278,7 +261,7 @@ class ToolbarTitle(Gtk.Bin):
             else:
                 self.__placeholder.set_text(title)
         else:
-            self.__placeholder.set_text(self.__uri)
+            self.__placeholder.set_text(uri)
         if not self.__popover.is_visible():
             self.__placeholder.set_opacity(0.8)
             self.set_text_entry("")
@@ -356,7 +339,7 @@ class ToolbarTitle(Gtk.Bin):
         if b:
             self.__indicator_stack.show()
             self.__indicator_stack.set_visible_child_name("image")
-            self.set_reading()
+            self.set_readable_button_state(False)
         else:
             self.__indicator_stack.hide()
 
@@ -422,14 +405,6 @@ class ToolbarTitle(Gtk.Bin):
         if not self.__entry.is_focus():
             self.__entry.grab_focus()
 
-    @property
-    def uri(self):
-        """
-            Get current uri
-            @return str
-        """
-        return self.__uri
-
     @property
     def progress(self):
         """
@@ -450,9 +425,8 @@ class ToolbarTitle(Gtk.Bin):
         """
         if self.__entry.get_icon_name(Gtk.EntryIconPosition.PRIMARY) ==\
                 "edit-copy-symbolic":
-            Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD).set_text(
-                self.__uri,
-                -1)
+            uri = self.__window.container.current.webview.uri
+            Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD).set_text(uri, -1)
 
     def _on_enter_notify(self, widget, event):
         """
@@ -462,13 +436,14 @@ class ToolbarTitle(Gtk.Bin):
         """
         if self.__popover.is_visible():
             return
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         if parsed.scheme in ["http", "https", "file"]:
             self.__entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY,
                                                  "edit-copy-symbolic")
             self.__entry.set_icon_tooltip_text(Gtk.EntryIconPosition.PRIMARY,
                                                _("Copy address"))
-            self.set_text_entry(self.__uri)
+            self.set_text_entry(uri)
         else:
             self.__set_default_placeholder()
 
@@ -498,12 +473,13 @@ class ToolbarTitle(Gtk.Bin):
         webview = self.__window.container.current.webview
         self.__action_image2.set_from_icon_name("edit-clear-symbolic",
                                                 Gtk.IconSize.MENU)
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         value = webview.get_current_text_entry()
         if value:
             self.set_text_entry(value)
         elif parsed.scheme in ["http", "https", "file"]:
-            self.set_text_entry(self.__uri)
+            self.set_text_entry(uri)
             self.__placeholder.set_opacity(0)
         else:
             self.__set_default_placeholder()
@@ -565,6 +541,13 @@ class ToolbarTitle(Gtk.Bin):
                 value = webview.get_prev_text_entry(uri)
             elif event.keyval == Gdk.KEY_Z:
                 value = webview.get_next_text_entry()
+            elif event.keyval == Gdk.KEY_Return:
+                bounds = self.__entry.get_selection_bounds()
+                if bounds:
+                    current = self.__entry.get_text()[:bounds[0]]
+                else:
+                    current = self.__entry.get_text()
+                value = current + ".com"
             if value is not None:
                 self.set_text_entry(value)
                 self.__entry.emit("changed")
@@ -587,15 +570,20 @@ class ToolbarTitle(Gtk.Bin):
                 GLib.idle_add(self.__window.close_popovers)
                 parsed = urlparse(uri)
                 # Search a missing scheme
-                if uri.find(".") != -1 and not parsed.scheme:
-                    db_uri = App().history.get_match(uri)
-                    if db_uri is not None:
-                        db_parsed = urlparse(db_uri)
-                        if db_parsed.netloc.startswith("www.") and\
-                                not parsed.netloc.startswith("www."):
-                            uri = "%s://www.%s" % (db_parsed.scheme, uri)
-                        else:
-                            uri = "%s://%s" % (db_parsed.scheme, uri)
+                if uri.find(".") != -1 and\
+                        uri.find(" ") == -1 and\
+                        not parsed.scheme:
+                    # Add missing www.
+                    if not uri.startswith("www."):
+                        db_uri = App().history.get_match("://www." + uri)
+                        if db_uri is not None:
+                            uri = "www." + uri
+                    # Add missing scheme
+                    db_uri = App().history.get_match("https://" + uri)
+                    if db_uri is None:
+                        uri = "http://" + uri
+                    else:
+                        uri = "https://" + uri
                 self.__window.container.load_uri(uri)
                 self.__window.container.set_expose(False)
                 if self.__entry_changed_id is not None:
@@ -611,8 +599,19 @@ class ToolbarTitle(Gtk.Bin):
             @param eventbox as Gtk.EventBox
             @param event as Gdk.Event
         """
-        self.__window.container.current.switch_read_mode()
-        self.set_reading()
+        view = self.__window.container.current
+        self.set_readable_button_state(not view.reading)
+        if view.reading:
+            view.stop_reading()
+        else:
+            js1 = Gio.File.new_for_uri(
+                "resource:///org/gnome/Eolie/Readability.js")
+            js2 = Gio.File.new_for_uri(
+                "resource:///org/gnome/Eolie/Readability_get.js")
+            (status, content1, tags) = js1.load_contents()
+            (status, content2, tags) = js2.load_contents()
+            script = content1.decode("utf-8") + content2.decode("utf-8")
+            view.webview.run_javascript(script, None, None)
         return True
 
     def _on_indicator2_press(self, eventbox, event):
@@ -748,7 +747,8 @@ class ToolbarTitle(Gtk.Bin):
         """
         self.__update_secure_content_indicator()
         self.__placeholder.set_opacity(0.8)
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         if parsed.scheme in ["http", "https", "file"]:
             self.set_text_entry("")
         else:
@@ -772,7 +772,8 @@ class ToolbarTitle(Gtk.Bin):
         """
             Update PRIMARY icon, Gtk.Entry should be set
         """
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         if (parsed.scheme == "https" and self.__secure_content) or\
                 parsed.scheme == "file":
             self.__entry.set_icon_from_icon_name(
@@ -821,6 +822,7 @@ class ToolbarTitle(Gtk.Bin):
         def model_append(array):
             if self.__completion_model_clear_timeout_id is not None:
                 GLib.source_remove(self.__completion_model_clear_timeout_id)
+                self.__completion_model_clear_timeout_id = None
             if self.__completion_model_append_timeout_id is not None:
                 GLib.source_remove(self.__completion_model_append_timeout_id)
             self.__completion_model_append_timeout_id = \
@@ -887,7 +889,7 @@ class ToolbarTitle(Gtk.Bin):
             @param popover as Gtk.popover
         """
         self.__cancellable.cancel()
-        self.__cancellable.reset()
+        self.__cancellable = Gio.Cancellable.new()
         self.__completion_model.clear()
         webview = self.__window.container.current.webview
         if popover == self.__popover:
@@ -920,7 +922,8 @@ class ToolbarTitle(Gtk.Bin):
                 return
         parsed = urlparse(value)
         is_uri = parsed.scheme in ["about, http", "file", "https", "populars"]
-        parsed = urlparse(self.__uri)
+        uri = self.__window.container.current.webview.uri
+        parsed = urlparse(uri)
         if value:
             self.__placeholder.set_opacity(0)
             # We are doing a search, show popover
@@ -951,7 +954,7 @@ class ToolbarTitle(Gtk.Bin):
         task_helper.run(self.__populate_completion, value)
 
         self.__cancellable.cancel()
-        self.__cancellable.reset()
+        self.__cancellable = Gio.Cancellable.new()
 
         network = Gio.NetworkMonitor.get_default().get_network_available()
         parsed = urlparse(value)
